@@ -13,7 +13,19 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-from .data import *  # noqa
+import warnings
+
+try:
+    from .data import *  # noqa
+except ImportError:
+    with warnings.catch_warnings():
+        warnings.simplefilter("always", ImportWarning)
+        warnings.warn(
+            "Missing packages, you will not be able to use archipel 'data' "
+            + "utils, others remain usable. To fix: pip install opencv numpy",
+            ImportWarning,
+        )
+
 from .msg import *  # noqa
 
-__version__ = "0.1.0"
+__version__ = "0.1.2"
